@@ -119,16 +119,24 @@ void Chuck_VM_Object::add_ref()
 //-----------------------------------------------------------------------------
 void Chuck_VM_Object::release()
 {
-    // check
+    //-----------------------------------------------------------------------------
+    // release is permitted even if ref-count is already 0 | 1.5.1.0 (ge)
+    //-----------------------------------------------------------------------------
     if( m_ref_count <= 0 )
     {
+        // print warning
+        EM_log( CK_LOG_FINEST, "(internal) Object.release() refcount already %d", m_ref_count );
+
         // print error
-        EM_error3( "[chuck]: (internal error) Object.release() refcount == %d", m_ref_count );
+        // EM_error3( "[chuck]: (internal error) Object.release() refcount == %d", m_ref_count );
         // make sure there is at least one reference
-        assert( m_ref_count > 0 );
+        // assert( m_ref_count > 0 );
+    }
+    else
+    {
+        // decrement
+        m_ref_count--;
     }
-    // decrement
-    m_ref_count--;
 
     // added 1.3.0.0
     // CK_VM_DEBUG(CK_FPRINTF_STDERR( "Chuck_VM_Object::release() : 0x%08x, %s, %ulu\n", this, mini_type(typeid(*this).name()), m_ref_count));
@@ -320,15 +328,20 @@ void Chuck_Object::help() // 1.4.1.0 (ge)
 
 
 
+//-----------------------------------------------------------------------------
+// name: Chuck_Array()
+// desc: constructor
+//-----------------------------------------------------------------------------
+Chuck_Array::Chuck_Array() { }
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: ~Chuck_Array()
 // desc: destructor
 //-----------------------------------------------------------------------------
-Chuck_Array::~Chuck_Array()
-{
-    // decrement reference count; added (ge): 1.4.1.0
-    CK_SAFE_RELEASE( m_array_type );
-}
+Chuck_Array::~Chuck_Array() { }
 
 
 
@@ -759,7 +772,7 @@ void Chuck_Array4::shuffle()
 // name: reverse()
 // desc: reverses array in-place
 //-----------------------------------------------------------------------------
-void Chuck_Array4::reverse( )
+void Chuck_Array4::reverse()
 {
     std::reverse( m_vector.begin(), m_vector.end() );
 }
@@ -767,6 +780,30 @@ void Chuck_Array4::reverse( )
 
 
 
+//-----------------------------------------------------------------------------
+// name: ck_compare_int()
+// desc: compare function for sorting uints as signed int
+//-----------------------------------------------------------------------------
+static bool ck_compare_sint( t_CKUINT lhs, t_CKUINT rhs )
+{
+    // sort by 2-norm / magnitude
+    return (t_CKINT)lhs < (t_CKINT)rhs;
+}
+//-----------------------------------------------------------------------------
+// name: sort()
+// desc: sort the array in ascending order
+//-----------------------------------------------------------------------------
+void Chuck_Array4::sort()
+{
+    // if object references sort as unsigned
+    if( m_is_obj ) std::sort( m_vector.begin(), m_vector.end() );
+    // if not object references, sort as signed ints
+    else std::sort( m_vector.begin(), m_vector.end(), ck_compare_sint );
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: back()
 // desc: ...
@@ -1258,6 +1295,18 @@ void Chuck_Array8::shuffle()
 
 
 
+//-----------------------------------------------------------------------------
+// name: sort()
+// desc: sort the array in ascending order
+//-----------------------------------------------------------------------------
+void Chuck_Array8::sort()
+{
+    std::sort( m_vector.begin(), m_vector.end() );
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: back()
 // desc: ...
@@ -1376,6 +1425,8 @@ Chuck_Array16::Chuck_Array16( t_CKINT capacity )
     m_vector.resize( capacity );
     // clear
     this->zero( 0, m_vector.capacity() );
+    // clear
+    m_isPolarType = FALSE;
 }
 
 
@@ -1711,6 +1762,74 @@ void Chuck_Array16::shuffle()
 
 
 
+//-----------------------------------------------------------------------------
+// name: ck_compare_polar()
+// desc: compare function for sorting chuck polar values
+//-----------------------------------------------------------------------------
+static bool ck_compare_polar( const t_CKCOMPLEX & lhs, const t_CKCOMPLEX & rhs )
+{
+    // cast to polar
+    const t_CKPOLAR * pL = (const t_CKPOLAR *)&lhs;
+    const t_CKPOLAR * pR = (const t_CKPOLAR *)&rhs;
+
+    // compare magnitude first
+    t_CKFLOAT x = pL->modulus;
+    t_CKFLOAT y = pR->modulus;
+    // if magnitude equal
+    if( x == y ) {
+        // compare phase
+        return pL->phase < pR->phase;
+    }
+    // return magnitude comparison
+    return x < y;
+}
+
+
+
+
+//-----------------------------------------------------------------------------
+// name: ck_compare_complex()
+// desc: compare function for sorting chuck complex values
+//-----------------------------------------------------------------------------
+static bool ck_compare_complex( const t_CKCOMPLEX & lhs, const t_CKCOMPLEX & rhs )
+{
+    // compare magnitude first
+    t_CKFLOAT x = ck_complex_magnitude(lhs);
+    t_CKFLOAT y = ck_complex_magnitude(rhs);
+    // if magnitude equal
+    if( x == y ) {
+        // compare phase
+        t_CKFLOAT xp = ck_complex_phase(lhs);
+        t_CKFLOAT yp = ck_complex_phase(rhs);
+        return xp < yp;
+    }
+    // return magnitude comparison
+    return x < y;
+}
+
+
+
+
+//-----------------------------------------------------------------------------
+// name: sort()
+// desc: sort the array in ascending order
+// NOTE: complex/polar type sort in chuck uses MATLAB convention:
+//       https://www.mathworks.com/help/matlab/ref/sort.html
+//       "By default, the sort function sorts complex values by their magnitude,
+//        and breaks ties using phase angles"
+//-----------------------------------------------------------------------------
+void Chuck_Array16::sort()
+{
+    // check betwen complex vs. polar
+    if( m_isPolarType )
+        std::sort( m_vector.begin(), m_vector.end(), ck_compare_polar );
+    else
+        std::sort( m_vector.begin(), m_vector.end(), ck_compare_complex );
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: back()
 // desc: ...
@@ -2272,6 +2391,42 @@ void Chuck_Array24::shuffle()
 
 
 
+//-----------------------------------------------------------------------------
+// name: ck_compare_vec3()
+// desc: compare function for sorting chuck vec3s
+//-----------------------------------------------------------------------------
+static bool ck_compare_vec3( const t_CKVEC3 & lhs, const t_CKVEC3 & rhs )
+{
+    // sort by 2-norm / magnitude
+    t_CKFLOAT x = ck_vec3_magnitude(lhs);
+    t_CKFLOAT y = ck_vec3_magnitude(rhs);
+    // if same
+    if( x == y )
+    {
+        // tie breakers
+        if( lhs.x < rhs.x ) return true;
+        if( lhs.y < rhs.y ) return true;
+        if( lhs.z < rhs.z ) return true;
+    }
+    return x < y;
+}
+
+
+
+
+//-----------------------------------------------------------------------------
+// name: sort()
+// desc: sort the array in ascending order
+// NOTE: sort vec3 by 2-norm (magnitude)
+//-----------------------------------------------------------------------------
+void Chuck_Array24::sort()
+{
+    std::sort( m_vector.begin(), m_vector.end(), ck_compare_vec3 );
+}
+
+
+
+
 //-----------------------------------------------------------------------------
 // name: Chuck_Array32()
 // desc: constructor
@@ -2730,6 +2885,43 @@ void Chuck_Array32::shuffle()
 
 
 
+//-----------------------------------------------------------------------------
+// name: ck_compare_vec4()
+// desc: compare function for sorting chuck vec4s
+//-----------------------------------------------------------------------------
+static bool ck_compare_vec4( const t_CKVEC4 & lhs, const t_CKVEC4 & rhs )
+{
+    // sort by 2-norm / magnitude
+    t_CKFLOAT x = ck_vec4_magnitude(lhs);
+    t_CKFLOAT y = ck_vec4_magnitude(rhs);
+    // if same
+    if( x == y )
+    {
+        // tie breakers
+        if( lhs.x < rhs.x ) return true;
+        if( lhs.y < rhs.y ) return true;
+        if( lhs.z < rhs.z ) return true;
+        if( lhs.w < rhs.w ) return true;
+    }
+    return x < y;
+}
+
+
+
+
+//-----------------------------------------------------------------------------
+// name: sort()
+// desc: sort the array in ascending order
+// NOTE: sort vec3 by 2-norm (magnitude)
+//-----------------------------------------------------------------------------
+void Chuck_Array32::sort()
+{
+    std::sort( m_vector.begin(), m_vector.end(), ck_compare_vec4 );
+}
+
+
+
+
 // Chuck_Event static instantiation
 t_CKUINT Chuck_Event::our_can_wait = 0;
 
