@@ -44,8 +44,8 @@
 #include <vector> // 1.5.0.0 (ge) | added
 
 
-static double g_pi = ONE_PI;
-static double g_twopi = TWO_PI;
+static double g_pi = CK_ONE_PI;
+static double g_twopi = CK_TWO_PI;
 static double g_e = ::exp( 1.0 );
 static t_CKFLOAT g_floatMax = CK_FLT_MAX;
 static t_CKFLOAT g_floatMin = CK_FLT_MIN;
@@ -76,6 +76,14 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     // add documentatiopn
     QUERY->doc_class( QUERY, "math class library." );
 
+    // add examples | 1.5.0.4 (ge) added
+    QUERY->add_ex( QUERY, "basic/blit2.ck" );
+    QUERY->add_ex( QUERY, "basic/mand-o-matic.ck" );
+    QUERY->add_ex( QUERY, "math/randomize.ck" );
+    QUERY->add_ex( QUERY, "math/maybe.ck" );
+    QUERY->add_ex( QUERY, "math/ind-dist.ck" );
+    QUERY->add_ex( QUERY, "math/map.ck" );
+
     // add abs
     QUERY->add_sfun( QUERY, abs_impl, "int", "abs" );
     QUERY->add_arg( QUERY, "int", "value" );
@@ -339,11 +347,17 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     // add srandom (1.3.1.0)
     QUERY->add_sfun( QUERY, srandom_impl, "void", "srandom" );
     QUERY->add_arg( QUERY, "int", "seed" );
-    QUERY->doc_func( QUERY, "Seed the random number generator. Different seeds will generate very different sequences of random numbers even if the seeds are close together. Alternatively, a deterministic sequence of pseudo-random numbers can repeatably generated by setting the same seed.");
+    QUERY->doc_func( QUERY, "Seed the random number generator (RNG). Different seeds will generate very different sequences of random numbers even if the seeds are close together. Alternatively, a deterministic sequence of pseudo-random numbers can repeatably generated by setting the same seed.");
+
+    // add randomize
+    QUERY->add_sfun( QUERY, randomize_impl, "void", "randomize" );
+    QUERY->doc_func( QUERY, "Randomize the seed of the random number generator (RNG), using an non-deterministic mechanism. Whereas srandom() explicitly seeds the RNG and will produce a deterministic sequence of pseudo-random numbers, randomize() \"shakes things up\" and causes RNG to start generating from a practically unpredicable seed. The quality of randomize() depends on the underlying implementation." );
 
     // go ahead and seed (the code can seed again for repeatability; 1.3.1.0)
     // updated to use ck_srandom() wrapper | 1.4.2.0 (ge)
-    ck_srandom( (unsigned)time( NULL ) );
+    // ck_srandom( (unsigned)time( NULL ) );
+    // updated to use ck_randomize() | 1.5.0.4 (ge)
+    ck_randomize();
 
     // add gauss (ge: added 1.3.5.3)
     QUERY->add_sfun( QUERY, gauss_impl, "float", "gauss" ); //! Gaussian function
@@ -439,10 +453,10 @@ DLL_QUERY libmath_query( Chuck_DL_Query * QUERY )
     QUERY->doc_var( QUERY, "An approximation of pi. (Same as global keyword 'pi'.)" );
 
     // twopi
-    QUERY->add_svar( QUERY, "float", "TWO_PI", TRUE, &g_twopi );
+    QUERY->add_svar( QUERY, "float", "two_pi", TRUE, &g_twopi );
     QUERY->doc_var( QUERY, "An approximation of 2*pi" );
     // twopi
-    QUERY->add_svar( QUERY, "float", "two_pi", TRUE, &g_twopi );
+    QUERY->add_svar( QUERY, "float", "TWO_PI", TRUE, &g_twopi );
     QUERY->doc_var( QUERY, "An approximation of 2*pi" );
 
     // e
@@ -685,7 +699,7 @@ CK_DLL_SFUN( max_impl )
 CK_DLL_SFUN( isinf_impl )
 {
     t_CKFLOAT x = GET_CK_FLOAT(ARGS);
-#ifdef __PLATFORM_WIN32__
+#ifdef __PLATFORM_WINDOWS__
     RETURN->v_int = !_finite( x );
 #else
     RETURN->v_int = isinf( x );
@@ -696,7 +710,7 @@ CK_DLL_SFUN( isinf_impl )
 CK_DLL_SFUN( isnan_impl )
 {
     t_CKFLOAT x = GET_CK_FLOAT(ARGS);
-#ifdef __PLATFORM_WIN32__
+#ifdef __PLATFORM_WINDOWS__
     RETURN->v_int = _isnan( x );
 #else
     RETURN->v_int = isnan( x );
@@ -815,7 +829,7 @@ CK_DLL_SFUN( rtop_impl )
     if( !from || !to )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.rtop( ... ) was given one or more NULL arrays..." );
+        EM_log( CK_LOG_WARNING, "Math.rtop(...) was given one or more NULL arrays..." );
         return;
     }
 
@@ -854,7 +868,7 @@ CK_DLL_SFUN( ptor_impl )
     if( !from || !to )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.ptor( ... ) was given one or more NULL arrays..." );
+        EM_log( CK_LOG_WARNING, "Math.ptor(...) was given one or more NULL arrays..." );
         return;
     }
 
@@ -893,8 +907,8 @@ CK_DLL_SFUN( random_impl )
 // randomf (added 1.3.1.0)
 CK_DLL_SFUN( randomf_impl )
 {
-    // 1.4.2.0 (ge) | updated to use ck_random() wrapper
-    RETURN->v_float = ( ck_random() / (t_CKFLOAT)CK_RANDOM_MAX );
+    // 1.5.0.4 (ge) | updated to use ck_random_f() wrapper
+    RETURN->v_float = ck_random_f();
 }
 
 
@@ -903,10 +917,10 @@ CK_DLL_SFUN( random2f_impl )
 {
     t_CKFLOAT min = GET_NEXT_FLOAT(ARGS);
     t_CKFLOAT max = GET_NEXT_FLOAT(ARGS);
-    // 1.4.2.0 (ge) | updated to use ck_random() wrapper
-    t_CKFLOAT normRand = ck_random() / (t_CKFLOAT)CK_RANDOM_MAX;
+    // 1.5.0.4 (ge) | updated to use ck_random_f() wrapper
+    t_CKFLOAT normRand = ck_random_f();
     //CK_FPRINTF_STDERR( "[chuck random2f]: %G --> %G, %G\n", normRand, min, max );
-    RETURN->v_float = min + (max-min)* normRand;
+    RETURN->v_float = min + (max-min) * normRand;
 }
 
 
@@ -925,12 +939,12 @@ CK_DLL_SFUN( random2_impl ) // inclusive.
         if( range > 0 )
         {
             // 1.4.2.0 (ge) | updated to use ck_random() wrapper
-            RETURN->v_int = min + (t_CKINT)( (1.0 + range) * ( ck_random()/(CK_RANDOM_MAX+1.0) ) );
+            RETURN->v_int = min + (t_CKINT)( (1.0 + range) * ( ck_random()/((t_CKFLOAT)CK_RANDOM_MAX) ) );
         }
         else
         {
             // 1.4.2.0 (ge) | updated to use ck_random() wrapper
-            RETURN->v_int = min - (t_CKINT)( (-range + 1.0) * ( ck_random()/(CK_RANDOM_MAX+1.0) ) );
+            RETURN->v_int = min - (t_CKINT)( (-range + 1.0) * ( ck_random()/((t_CKFLOAT)CK_RANDOM_MAX) ) );
         }
     }
 }
@@ -945,6 +959,14 @@ CK_DLL_SFUN( srandom_impl )
 }
 
 
+// randomize (added 1.5.0.4)
+CK_DLL_SFUN( randomize_impl )
+{
+    // undo the seeding with some non-determinism
+    ck_randomize();
+}
+
+
 // gauss (ge: added 1.3.5.3)
 CK_DLL_SFUN( gauss_impl )
 {
@@ -953,7 +975,7 @@ CK_DLL_SFUN( gauss_impl )
     t_CKFLOAT sd = GET_NEXT_FLOAT(ARGS);
 
     // compute gaussian
-    RETURN->v_float = (1.0 / (sd*::sqrt(TWO_PI))) * ::exp( -(x-mu)*(x-mu) / (2*sd*sd) );
+    RETURN->v_float = (1.0 / (sd*::sqrt(CK_TWO_PI))) * ::exp( -(x-mu)*(x-mu) / (2*sd*sd) );
 }
 
 
@@ -971,7 +993,7 @@ CK_DLL_SFUN( cossim_impl )
     if( a == NULL || b == NULL )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.cossim( ... ) was given one or more NULL arrays..." );
+        EM_log( CK_LOG_WARNING, "Math.cossim(...) was given one or more NULL arrays..." );
         // error out
         return;
     }
@@ -982,7 +1004,7 @@ CK_DLL_SFUN( cossim_impl )
     if( size == 0 )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.cossim( ... ) was given one or more 0-length arrays..." );
+        EM_log( CK_LOG_WARNING, "Math.cossim(...) was given one or more 0-length arrays..." );
         // error out
         return;
     }
@@ -1032,7 +1054,7 @@ CK_DLL_SFUN( cossim3d_impl )
     if( norm1 == 0 || norm2 == 0 )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.cossim( ... ) zero in denominator..." );
+        EM_log( CK_LOG_WARNING, "Math.cossim(...) zero in denominator..." );
         // error out
         return;
     }
@@ -1074,7 +1096,7 @@ CK_DLL_SFUN( cossim4d_impl )
     if( norm1 == 0 || norm2 == 0 )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.cossim( ... ) zero in denominator..." );
+        EM_log( CK_LOG_WARNING, "Math.cossim(...) zero in denominator..." );
         // error out
         return;
     }
@@ -1099,7 +1121,7 @@ CK_DLL_SFUN( euclidean_impl )
     if( a == NULL || b == NULL )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.cossim( ... ) was given one or more NULL arrays..." );
+        EM_log( CK_LOG_WARNING, "Math.cossim(...) was given one or more NULL arrays..." );
         // error out
         return;
     }
@@ -1110,7 +1132,7 @@ CK_DLL_SFUN( euclidean_impl )
     if( size == 0 )
     {
         // log
-        EM_log( CK_LOG_WARNING, "Math.cossim( ... ) was given one or more 0-length arrays..." );
+        EM_log( CK_LOG_WARNING, "Math.cossim(...) was given one or more 0-length arrays..." );
         // error out
         return;
     }
