@@ -118,7 +118,10 @@
 
 #define VERSION "1.0.10"
 
-#ifdef __MACOSX_CORE__
+// 1.5.0.7 (ge) since this file does not...
+// include chuck_def.h, directly check platform macros
+
+#if     defined(__APPLE__) // macOS
 #define CPU_CLIPS_POSITIVE 1
 #ifdef __LITTLE_ENDIAN__
 #define CPU_IS_BIG_ENDIAN 0
@@ -136,7 +139,7 @@
 #define TYPEOF_SF_COUNT_T off_t
 #endif
 
-#if     defined(__PLATFORM_WIN32__) //Dev Studio
+#if     defined(_WIN32) // windows
 #define CPU_CLIPS_POSITIVE 0
 #define CPU_IS_BIG_ENDIAN 0
 #define CPU_IS_LITTLE_ENDIAN 1
@@ -151,7 +154,7 @@
 #define TYPEOF_SF_COUNT_T off_t
 #endif
 
-#if     defined (__WINDOWS_PTHREAD__) //Cygwin
+#if     defined (__CYGWIN__) // cygwin
 #define CPU_CLIPS_POSITIVE 0
 #define CPU_IS_BIG_ENDIAN 0
 #define CPU_IS_LITTLE_ENDIAN 1
@@ -162,11 +165,12 @@
 #define TYPEOF_SF_COUNT_T off_t
 #endif
 
-#ifdef __LINUX_ALSA__
-#define HAVE_ALSA_ASOUNDLIB_H
-#endif
+// 1.5.0.7 (ge) commented out, not used
+// #ifdef __LINUX_ALSA__
+// #define HAVE_ALSA_ASOUNDLIB_H
+// #endif
 
-#if defined(__PLATFORM_LINUX__)
+#if defined(__linux__) // Linux
 #define CPU_CLIPS_POSITIVE 0
 #define CPU_IS_BIG_ENDIAN 0
 #define CPU_IS_LITTLE_ENDIAN 1
@@ -184,7 +188,7 @@
 #define HAVE_LRINT 1
 #endif
 
-#ifdef __EMSCRIPTEN__
+#ifdef __EMSCRIPTEN__ // web assembly
 #define CPU_CLIPS_POSITIVE 1
 #define CPU_IS_BIG_ENDIAN 0
 #define CPU_IS_LITTLE_ENDIAN 1
@@ -203,7 +207,7 @@
 // in the microsoft vc6 compiler...
 // and other ms win32 specialteez.
 
-#ifdef __PLATFORM_WIN32__
+#ifdef _WIN32
 
 #define C_INLINE __inline
 #define SF_COUNT_MAX 0x7FFFFFFFFFFFFFFF
@@ -1748,7 +1752,13 @@ enum
 {
   /* keep sorted for wav_w64_format_str() */
     WAVE_FORMAT_UNKNOWN                 = 0x0000,       /* Microsoft Corporation */
-    WAVE_FORMAT_PCM                     = 0x0001,       /* Microsoft PCM format */
+    WAVE_FORMAT_MS_PCM                  = 0x0001,       /* Microsoft PCM format */
+    /* -------------------------------------------------------------------------
+    creating and using WAVE_FORMAT_MS_PCM in this module, as WAVE_FORMAT_PCM may
+    be defined by windows, e.g., in mmeapi.h -- which breaks the build...thanks
+    important: WAVE_FORMAT_MS_PCM must be 1, as WAV format tag | 1.5.0.0 (ge)
+    ------------------------------------------------------------------------- */
+    /* WAVE_FORMAT_PCM                  = 0x0001, */    /* Microsoft PCM format */
     WAVE_FORMAT_MS_ADPCM                = 0x0002,       /* Microsoft ADPCM */
     WAVE_FORMAT_IEEE_FLOAT              = 0x0003,       /* Micrososft 32 bit float format */
     WAVE_FORMAT_VSELP                   = 0x0004,       /* Compaq Computer Corporation */
@@ -2490,7 +2500,7 @@ extern word gsm_FAC [8] ;
     #define __USE_ISOC99    1
 
 
-#elif ( defined (WIN32) || defined (_WIN32) || defined(__PLATFORM_WIN32__) || defined(__LITTLE_ENDIAN__) )
+#elif ( defined (WIN32) || defined (_WIN32) || defined(__PLATFORM_WINDOWS__) || defined(__LITTLE_ENDIAN__) )
 
     #undef      HAVE_LRINT_REPLACEMENT
     #define     HAVE_LRINT_REPLACEMENT  1
@@ -2501,7 +2511,8 @@ extern word gsm_FAC [8] ;
     */
 
 // ge: some versions of windows have them
-#ifndef __WINDOWS_MODERN__
+// 1.5.0.7 (ge) make "__WINDOWS_MODERN__" default
+#ifdef __WINDOWS_OLDSCHOOL__ // was: #ifndef __WINDOWS_MODERN__
     __inline long int
     lrint (double flt)
     {   int intgr ;
